@@ -632,7 +632,7 @@ def alignGPModel(model, data, response): #Aligns a model
     if np.isnan(np.array(prediction)).any() or np.isnan(np.array(response)).any() or not np.isfinite(np.array(prediction,dtype=np.float32)).all():
         return model
     try:
-        align=np.polyfit(prediction,response,1,rcond=1e-16)#np.round(np.polyfit(prediction,response,1,rcond=1e-16),decimals=14)
+        align=np.round(np.polyfit(prediction,response,1,rcond=1e-16),decimals=14)#np.polyfit(prediction,response,1,rcond=1e-16)#np.round(np.polyfit(prediction,response,1,rcond=1e-16),decimals=14)
     except np.linalg.LinAlgError:
         #print("Alignment failed for: ", model, " with prediction: ", prediction, "and reference data: ", response)
         return model
@@ -688,7 +688,7 @@ def evolve(inputData, responseData, generations=100, ops=defaultOps(), const=def
 
         #paretoModels=paretoTournament(models)
         paretoModels=selectModels(models,elitismRate/100*popSize if elitismRate/100*popSize<len(models) else len(models))
-        if extinction and i%extinctionRate:
+        if extinction and i%extinctionRate==0 and i>0:
             models=initializeGPModels(variableCount,ops,const,popSize)
             for mods in models:
                 setModelQuality(mods,inData,resData,modelEvaluationMetrics=metrics)
